import os

from ruamel import yaml

import great_expectations as gx

context = gx.get_context()

assert context
